@@ -147,6 +147,42 @@ class ArticleDownloader:
 
     return list(set(dois))
 
+  @traced
+  def get_html_from_doi(self, doi, writefile, mode):
+    '''
+    Downloads and writes an HTML article to a file, given a DOI and operating mode
+
+    :param doi: DOI string for the article we want to download
+    :type doi: str
+
+    :param writefile: file object to write to
+    :type writefile: file
+
+    :param mode: either 'elsevier', depending on how we wish to access the file
+    :type mode: str
+
+    :returns: True on successful write, False otherwise
+    :rtype: bool
+    '''
+
+    if mode == 'elsevier':
+      if self.check_els_entitlement(doi):
+        try:
+          html_url='http://api.elsevier.com/content/article/doi:' + doi + '?view=FULL'
+          headers = {
+            'X-ELS-APIKEY': self.els_api_key,
+            'Accept': 'text/html'
+          }
+
+          r = requests.get(html_url, stream=True, headers=headers)
+          if r.status_code == 200:
+            for chunk in r.iter_content(2048):
+              writefile.write(chunk)
+            return True
+        except:
+          # API download limit exceeded
+          return False
+      return False
 
   @traced
   def get_pdf_from_doi(self, doi, writefile, mode):
@@ -264,19 +300,67 @@ class ArticleDownloader:
 
       return False
 
-    if mode == 'springer':
-      base_url = 'http://link.springer.com/content/pdf/'
-      api_url = base_url + doi + '.pdf'
+    if mode == 'nature':
+      scraper = scrapers.Nature()
+      scrape_url = 'http://dx.doi.org/' + doi
+      download_url = None
+
+      r = requests.get(scrape_url)
+      if r.status_code == 200:
+        scraper.feed(r.content)
+
+        if scraper.download_link is not None:
+          download_url = scraper.download_link
+
+      if download_url is not None:
+        headers = {
+          'Accept': 'application/pdf'
+        }
+        r = requests.get(download_url, stream=True, headers=headers)
+        if r.status_code == 200:
+          try:
+            for chunk in r.iter_content(2048):
+              writefile.write(chunk)
+            return True
+          except:
+            return False
+
+      return False
+
+    if mode == 'acs':
+      base_url = 'http://pubs.acs.org/doi/pdf/'
+      api_url = base_url + doi
 
       try:
         headers = {
-          'Accept': 'application/pdf'
+          'Accept': 'application/pdf',
+          'User-agent': 'Mozilla/5.0'
         }
         r = requests.get(api_url, stream=True, headers=headers)
         if r.status_code == 200:
           for chunk in r.iter_content(2048):
             writefile.write(chunk)
-            return True
+          return True
+      except:
+        return False
+      return False
+
+    return False
+
+    if mode == 'springer':
+      base_url = 'http://link.springer.com/content/pdf/'
+      api_url = base_url + doi
+
+      try:
+        headers = {
+          'Accept': 'application/pdf',
+          'User-agent': 'Mozilla/5.0'
+        }
+        r = requests.get(api_url, stream=True, headers=headers)
+        if r.status_code == 200:
+          for chunk in r.iter_content(2048):
+            writefile.write(chunk)
+          return True
       except:
         return False
       return False
